
# The different «fontFamily» options to show
options = [
	"Verdana"
	"Trebuchet MS"
	"Georgia"
	"Menlo"
	"Copperplate"
	"Brush Script MT, cursive"
	Utils.loadWebFont "Oswald"
	Utils.loadWebFont "Cookie"
	Utils.loadWebFont "Lato", 100
]


# Functions for the slider

# round number to a set amount
round = (number, nearest) ->
	Math.round(number / nearest) * nearest


# - add dots for increments to slider
# - enforce increments
# - change title on value change

applyIncrements = (slider,options) ->
	
	latestOption = null
	
	sizeOfDots = slider.height + 2
	stepAmount = options.length
	
	stepDistanceDots = ( slider.width - sizeOfDots ) / ( stepAmount - 1 )
	stepDistanceKnob = slider.width / ( stepAmount - 1 )
	
	for i in [0...stepAmount]
		dot = new Layer 
			size: sizeOfDots
			borderRadius: sizeOfDots / 1.5
			superLayer: slider
			backgroundColor: artboard.backgroundColor
			x: (stepDistanceDots * i)
		
		dot.placeBehind slider.knob
		dot.y = Align.center
	
	slider.min = 0
	slider.max = stepAmount-1
	
	slider.onValueChange ->
		if options[Utils.round @value] isnt latestOption
			# make the text a bit smaller
			theTextLayer.scale = 0.95
			# apply the new value
			theTextLayer.fontFamily = options[Utils.round @value]
			# scale back up
			theTextLayer.animate
				scale: 1
				options:
					time: .3
					curve: "Spring"
			
			latestOption = options[Utils.round @value]
		
		if Utils.round @value is 0
			title.template =
				v: ""
				d: "«default»"
		else if options[Utils.round @value].fontFamily
			if options[Utils.round @value].fontWeight
				title.template =
					v: "Utils.loadWebFont \"#{ options[Utils.round @value].fontFamily }\", #{ options[Utils.round @value].fontWeight }"
					d: ""
			else
				title.template =
					v: "Utils.loadWebFont \"#{ options[Utils.round @value].fontFamily }\""
					d: ""
		else
			title.template =
				v: "\"#{options[Utils.round @value]}\""
				d: ""
	
	slider.knob.draggable.updatePosition = (point) ->
		point.x = round(point.x, stepDistanceKnob) - (slider.knob.width / 2)
		return point

# Setup title

title.template =
	v: ""
	d: "«default»"

if Screen.height > Screen.width		# portrait orientation ?
	if Screen.height <= 667			# on an iPhone 6 (or smaller) ?
		title.fontSize = 11.5

# Setup white background
if Screen.height > Screen.width		# portrait orientation ?
	if Screen.height <= 667			# on an iPhone 6 (or smaller) ?
		whiteBackground.y = 50
		whiteBackground.height = 552

# Setup Text Layer

# This cannot be set in Design
theTextLayer.autoHeight = yes

# Slider
slider = new SliderComponent
	height: 5
	width: Screen.width - 50
	knobSize: 25
	backgroundColor: "rgba(255,255,255,0.5)"
	x: 25
	maxY: Screen.height - 30
slider.fill.backgroundColor = "#fff"

# add interval points to the slider
applyIncrements slider, options
